import { useState } from 'react';

const QueryTeam = () => {
	const [date, setDate] = useState('');
	const [pushNotification, setPushNotification] = useState(false);
	const [teamImage, setTeamImage] = useState(''); // 預設團隊圖片的URL
	const [imageError, setImageError] = useState(false); // 圖片加載錯誤狀態

	const handleQuery = async () => {
		// 處理查詢邏輯
		try {
			const data = JSON.stringify({
				date: date,
				isNotify: pushNotification,
			});

			const response = await fetch('https://api.jianmiau.tk/getBadminton', {
				method: 'POST',
				headers: {
					'Content-Type': 'application/json',
				},
				body: data,
			});

			if (response.ok) {
				const blob = await response.blob(); // 獲取 blob 形式的圖片
				const url = URL.createObjectURL(blob);
				setTeamImage(url); // 設置圖片 URL
				setImageError(false); // 圖片加載正常
			} else {
				throw new Error('網絡錯誤');
			}
		} catch (error) {
			console.error(error);
			setImageError(true); // 圖片加載錯誤
		}
	};

	// 圖片加載失敗時處理
	const handleImageError = () => {
		setImageError(true); // 如果圖片加載失敗，設定錯誤狀態為 true
	};

	return (
		<div className="query-team-container">
			<h2>查詢隊伍</h2>
			<form>
				<label>
					日期:
					<input type="text" value={date} onChange={(e) => setDate(e.target.value)} placeholder="YYYYMMDD" />
				</label>

				<div className="checkbox-container">
					<input
						type="checkbox"
						checked={pushNotification}
						onChange={() => setPushNotification(!pushNotification)}
					/>
					是否推送
				</div>
				<button type="button" onClick={handleQuery}>
					查詢
				</button>
			</form>

			{/* 團隊圖片，如果 teamImage 有值才顯示 */}
			{!imageError && teamImage && (
				<div className="team-image-container">
					<img
						src={teamImage}
						alt="隊伍圖片"
						className="team-image"
						onError={handleImageError}
					/>
				</div>
			)}
		</div>
	);
};

export default QueryTeam;
